@@ -1,4 +1,5 @@
 from django.contrib import admin
+from mptt.admin import MPTTModelAdmin
 from ccpages.models import Page, PageImage, PageAttachment
 from ccpages.forms import PageAdminForm
 
@@ -11,7 +12,7 @@ class PageAttachmentInline(admin.TabularInline):
     model = PageAttachment
 
 
-class PageAdmin(admin.ModelAdmin):
+class PageAdmin(MPTTModelAdmin):
     form = PageAdminForm
     search_fields = (
             'title',
@@ -20,8 +21,8 @@ class PageAdmin(admin.ModelAdmin):
             'status',)
     list_display = (
             'title',
-            'order',
-            'status')
+            'status',
+            'order',)
     list_editable = (
             'order',
             'status',)
@@ -46,5 +47,4 @@ class PageAdmin(admin.ModelAdmin):
         })
     )
 
-
 admin.site.register(Page, PageAdmin)
